==> geant4_10.7.4.orig.tar.gz: geant4-10.7.4/source/run/sources.cmake <==
#------------------------------------------------------------------------------
# Module : G4run
# Package: Geant4.src.G4run
#------------------------------------------------------------------------------

#
# Define the Geant4 Module.
#
geant4_define_module(NAME G4run
  HEADERS
    G4AdjointPrimaryGeneratorAction.hh
    G4AdjointSimManager.hh
    G4AdjointSimMessenger.hh
    G4ExceptionHandler.hh
    G4MSSteppingAction.hh
    G4MatScanMessenger.hh
    G4MaterialScanner.hh
    G4PhysicsListHelper.hh
    G4PhysicsListOrderingParameter.hh
    G4PhysicsListWorkspace.hh
    G4Run.hh
    G4RunManager.hh
    G4MTRunManager.hh
    G4WorkerRunManager.hh
    G4RunManagerKernel.hh
    G4MTRunManagerKernel.hh
    G4WorkerRunManagerKernel.hh
    G4RunMessenger.hh
    G4UserPhysicsListMessenger.hh
    G4UserRunAction.hh
    G4MultiRunAction.hh
    G4UserWorkerInitialization.hh
    G4UserWorkerThreadInitialization.hh
    G4VModularPhysicsList.hh
    G4VPersistencyManager.hh
    G4VPhysicsConstructor.hh
    G4VUserActionInitialization.hh
    G4VUserDetectorConstruction.hh
    G4VUserParallelWorld.hh
    G4VUserPhysicsList.hh
    G4VUserPrimaryGeneratorAction.hh
    G4WorkerThread.hh
    G4VUPLSplitter.hh
    rundefs.hh
    G4RNGHelper.hh
    G4PhysicsBuilderInterface.hh
  SOURCES
    G4AdjointPrimaryGeneratorAction.cc
    G4AdjointSimManager.cc
    G4AdjointSimMessenger.cc
    G4ExceptionHandler.cc
    G4MSSteppingAction.cc
    G4MatScanMessenger.cc
    G4MaterialScanner.cc
    G4PhysicsListHelper.cc
    G4PhysicsListOrderingParamater.cc
    G4PhysicsListWorkspace.cc
    G4Run.cc
    G4RunManager.cc
    G4MTRunManager.cc
    G4WorkerRunManager.cc
    G4RunManagerKernel.cc
    G4MTRunManagerKernel.cc
    G4WorkerRunManagerKernel.cc
    G4RunMessenger.cc
    G4UserPhysicsListMessenger.cc
    G4UserRunAction.cc
    G4MultiRunAction.cc
    G4UserWorkerInitialization.cc
    G4UserWorkerThreadInitialization.cc
    G4VModularPhysicsList.cc
    G4VPersistencyManager.cc
    G4VUserActionInitialization.cc
    G4VUserDetectorConstruction.cc
    G4VUserParallelWorld.cc
    G4VPhysicsConstructor.cc
    G4VUserPhysicsList.cc
    G4VUserPrimaryGeneratorAction.cc
    G4WorkerThread.cc
    G4RNGHelper.cc
  GRANULAR_DEPENDENCIES
    G4cuts
    G4decay
    G4detector
    G4detutils
    G4digits
    G4emutils
    G4event
    G4geombias
    G4geometrymng
    G4globman
    G4graphics_reps
    G4hepnumerics
    G4hits
    G4intercoms
    G4magneticfield
    G4materials
    G4navigation
    G4partman
    G4procman
    G4scoring
    G4track
    G4tracking
    G4transportation
    G4volumes
    G4specsolids
  GLOBAL_DEPENDENCIES
    G4digits_hits
    G4event
    G4geometry
    G4global
    G4graphics_reps
    G4intercoms
    G4materials
    G4particles
    G4processes
    G4ptl
    G4track
    G4tracking
  LINK_LIBRARIES
    ${timemory_LIBRARIES}
)

# List any source specific properties here
if(GEANT4_BUILD_BUILTIN_BACKTRACE)
  geant4_module_compile_definitions(G4run PRIVATE G4BT_DEBUG)
endif()

==> geant4.11.00.b01.tar.gz: geant4.11.00.b01/source/run/sources.cmake <==
# - G4run module build definition

# Define the Geant4 Module.
geant4_add_module(G4run
  PUBLIC_HEADERS
    G4AdjointPrimaryGeneratorAction.hh
    G4AdjointSimManager.hh
    G4AdjointSimMessenger.hh
    G4ExceptionHandler.hh
    G4MSSteppingAction.hh
    G4MatScanMessenger.hh
    G4MaterialScanner.hh
    G4PhysicsListHelper.hh
    G4PhysicsListOrderingParameter.hh
    G4PhysicsListWorkspace.hh
    G4Run.hh
    G4RunManager.hh
    G4MTRunManager.hh
    G4WorkerRunManager.hh
    G4RunManagerKernel.hh
    G4MTRunManagerKernel.hh
    G4WorkerRunManagerKernel.hh
    G4RunMessenger.hh
    G4UserPhysicsListMessenger.hh
    G4UserRunAction.hh
    G4MultiRunAction.hh
    G4UserWorkerInitialization.hh
    G4UserWorkerThreadInitialization.hh
    G4VModularPhysicsList.hh
    G4VPersistencyManager.hh
    G4VPhysicsConstructor.hh
    G4VUserActionInitialization.hh
    G4VUserDetectorConstruction.hh
    G4VUserParallelWorld.hh
    G4VUserPhysicsList.hh
    G4VUserPrimaryGeneratorAction.hh
    G4WorkerThread.hh
    G4VUPLSplitter.hh
    rundefs.hh
    G4RNGHelper.hh
    G4PhysicsBuilderInterface.hh
  SOURCES
    G4AdjointPrimaryGeneratorAction.cc
    G4AdjointSimManager.cc
    G4AdjointSimMessenger.cc
    G4ExceptionHandler.cc
    G4MSSteppingAction.cc
    G4MatScanMessenger.cc
    G4MaterialScanner.cc
    G4PhysicsListHelper.cc
    G4PhysicsListOrderingParamater.cc
    G4PhysicsListWorkspace.cc
    G4Run.cc
    G4RunManager.cc
    G4MTRunManager.cc
    G4WorkerRunManager.cc
    G4RunManagerKernel.cc
    G4MTRunManagerKernel.cc
    G4WorkerRunManagerKernel.cc
    G4RunMessenger.cc
    G4UserPhysicsListMessenger.cc
    G4UserRunAction.cc
    G4MultiRunAction.cc
    G4UserWorkerInitialization.cc
    G4UserWorkerThreadInitialization.cc
    G4VModularPhysicsList.cc
    G4VPersistencyManager.cc
    G4VUserActionInitialization.cc
    G4VUserDetectorConstruction.cc
    G4VUserParallelWorld.cc
    G4VPhysicsConstructor.cc
    G4VUserPhysicsList.cc
    G4VUserPrimaryGeneratorAction.cc
    G4WorkerThread.cc
    G4RNGHelper.cc)

geant4_module_link_libraries(G4run
  PUBLIC
    G4cuts
    G4event
    G4globman
    G4heprandom
    G4intercoms
    G4partman
    G4tracking
  PRIVATE
    G4bosons
    G4detector
    G4detutils
    G4emutils
    G4geometrymng
    G4graphics_reps
    G4hadronic_util
    G4hepnumerics
    G4hits
    G4ions
    G4magneticfield
    G4materials
    G4navigation
    G4procman
    G4scoring
    G4specsolids
    G4track
    G4tracking
    G4transportation
    G4volumes
    ${timemory_LIBRARIES})

# List any source specific properties here
if(GEANT4_BUILD_BUILTIN_BACKTRACE)
  geant4_module_compile_definitions(G4run PRIVATE G4BT_DEBUG)
endif()
